#ifndef PYTHONIC_INCLUDE_NUMPY_LESS_EQUAL_ACCUMULATE_HPP
#define PYTHONIC_INCLUDE_NUMPY_LESS_EQUAL_ACCUMULATE_HPP

#define UFUNC_NAME less_equal
#include "pythonic/include/numpy/ufunc_accumulate.hpp"

#endif
