#ifndef PYTHONIC_INCLUDE_NUMPY_LOGICAL_AND_ACCUMULATE_HPP
#define PYTHONIC_INCLUDE_NUMPY_LOGICAL_AND_ACCUMULATE_HPP

#define UFUNC_NAME logical_and
#include "pythonic/include/numpy/ufunc_accumulate.hpp"

#endif
